pub struct MlDsaKeyManager { /* private fields */ }Expand description
Key management for ML-DSA
Implementations
Sourceimpl MlDsaKeyManager
impl MlDsaKeyManager
Sourcepub fn generate_key(&mut self, key_id: String) -> Result<(), MlDsaError>
pub fn generate_key(&mut self, key_id: String) -> Result<(), MlDsaError>
Generate and store new key
Sourcepub fn get_signer(&self, key_id: &str) -> Option<Arc<Mutex<MlDsaSigner>>>
pub fn get_signer(&self, key_id: &str) -> Option<Arc<Mutex<MlDsaSigner>>>
Get signer by key ID
Sourcepub fn get_default_signer(&self) -> Option<Arc<Mutex<MlDsaSigner>>>
pub fn get_default_signer(&self) -> Option<Arc<Mutex<MlDsaSigner>>>
Get default signer
Sourcepub fn remove_key(&mut self, key_id: &str) -> Result<(), MlDsaError>
pub fn remove_key(&mut self, key_id: &str) -> Result<(), MlDsaError>
Remove key
Sourcepub fn should_rotate_key(
&self,
_key_id: &str,
signature_count: u64,
key_age_seconds: u64,
) -> bool
pub fn should_rotate_key( &self, _key_id: &str, signature_count: u64, key_age_seconds: u64, ) -> bool
Check if a key should be rotated based on the rotation policy. Returns true if the key has exceeded its maximum signature count or the rotation interval has elapsed.
Sourcepub fn rotation_policy(&self) -> &KeyRotationPolicy
pub fn rotation_policy(&self) -> &KeyRotationPolicy
Get the current key rotation policy