pub enum VcError {
InvalidSignature,
Expired,
UngroundedIssuer,
DecodeTooShort,
DecodeBadClaimCount,
}Variants
InvalidSignature
The signature does not verify against the issuer key over the credential bytes.
Expired
now is past valid_until.
UngroundedIssuer
The issuer is an ungrounded artificial agent (no Principal) — agency.n3 G1’.
DecodeTooShort
The binary payload is too short to parse a Credential header.
DecodeBadClaimCount
The binary payload is too short for the declared claim count.