verify_grounded

Function verify_grounded 

pub fn verify_grounded(
    credential: &Credential,
    issuer_key: &VerifyingKey,
    signature: &Signature,
    now: u32,
    index: &QuinIndex,
) -> Result<(), VcError>
Verify as verify, and additionally reject the credential if its issuer is an ungrounded artificial agent in index (agency.n3 G1’ — no human Principal behind it).