pub struct ProofVerifier { /* private fields */ }Expand description
Proof verifier for validating zk-SNARKs
Implementations
Sourceimpl ProofVerifier
impl ProofVerifier
Sourcepub fn generate_verifying_key(
&self,
circuit: &ArithmeticCircuit,
) -> Result<VerifyingKey, ZkError>
pub fn generate_verifying_key( &self, circuit: &ArithmeticCircuit, ) -> Result<VerifyingKey, ZkError>
Generate verifying key
Derived from the same circuit structure as the proving key but with a
separate domain separator, then XOR-folded with an independent SHA3-512
hash so the two keys are related but cryptographically distinct.
Bytes [0..8] are set to b"QUALAVK\x01".
Sourcepub fn store_verifying_key(
&mut self,
circuit_id: String,
verifying_key: VerifyingKey,
)
pub fn store_verifying_key( &mut self, circuit_id: String, verifying_key: VerifyingKey, )
Store verifying key
Sourcepub fn get_verifying_key(&self, key_id: &str) -> Result<&VerifyingKey, ZkError>
pub fn get_verifying_key(&self, key_id: &str) -> Result<&VerifyingKey, ZkError>
Get verifying key