pub struct LayerFetchReport {
pub adapter_id: String,
pub endpoint: String,
pub bbox: (f64, f64, f64, f64),
pub time_range: (u64, u64),
pub estimated_tile_count: u32,
pub status: LayerFetchStatus,
}Expand description
Structured report describing what a layer fetch would request.
Fields
adapter_id: Stringendpoint: Stringbbox: (f64, f64, f64, f64)time_range: (u64, u64)estimated_tile_count: u32status: LayerFetchStatusTrait Implementations
Sourceimpl Clone for LayerFetchReport
impl Clone for LayerFetchReport
Sourcefn clone(&self) -> LayerFetchReport
fn clone(&self) -> LayerFetchReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LayerFetchReport
impl Debug for LayerFetchReport
Sourceimpl PartialEq for LayerFetchReport
impl PartialEq for LayerFetchReport
Sourcefn eq(&self, other: &LayerFetchReport) -> bool
fn eq(&self, other: &LayerFetchReport) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LayerFetchReport