pub struct SuspendedTransactionQueue {
pub queue: [Option<SuspendedTransaction>; 32],
}Expand description
A fixed-size pending queue for Webizen VM transactions waiting on M:N Guardianship signatures.
Fields
queue: [Option<SuspendedTransaction>; 32]Implementations
Sourceimpl SuspendedTransactionQueue
impl SuspendedTransactionQueue
pub const fn new() -> Self
Sourcepub fn push(
&mut self,
transaction: SuspendedTransaction,
) -> Result<(), &'static str>
pub fn push( &mut self, transaction: SuspendedTransaction, ) -> Result<(), &'static str>
Pushes a flattened execution frame to the pending queue.
Sourcepub fn apply_consensus_token(
&mut self,
token_quin: &NQuin,
) -> Option<SuspendedTransaction>
pub fn apply_consensus_token( &mut self, token_quin: &NQuin, ) -> Option<SuspendedTransaction>
Asynchronously wakes up a suspended transaction if the signature threshold is met by an incoming WebRTC token.