pub struct Norm {
pub weight: u8,
pub exemptive: bool,
pub immune: bool,
}Expand description
A norm participating in a conflict: effective binding weight, whether it is an Exemptive (derogation/waiver), and whether it is IMMUNE — non-derogable, a Hohfeldian immunity (e.g. ICCPR Art. 4(2): no derogation from the right to life, freedom from torture, etc.).
Fields
weight: u8exemptive: boolimmune: boolImplementations