pub struct SubThresholdOrchestrator { /* private fields */ }Expand description
Sub-threshold orchestrator
Implementations
Sourceimpl SubThresholdOrchestrator
impl SubThresholdOrchestrator
Sourcepub fn optimize_for_sub_threshold(
&mut self,
computation: SubThresholdComputation,
) -> SubThresholdComputation
pub fn optimize_for_sub_threshold( &mut self, computation: SubThresholdComputation, ) -> SubThresholdComputation
Optimize computation for sub-threshold operation.
Uses the resource allocator to check available compute units and scales the computation’s resource requirements accordingly. The orchestration policy influences the reduction factor:
PowerEfficiency: 50% compute, 40% power, 50% thermalThermalAware: 60% compute, 50% power, 60% thermalPerformanceFirst: 90% compute, 80% power, 80% thermalAdaptive/other: 70% compute, 50% power, 60% thermal
Sourcepub fn workload_analyzer_mut(&mut self) -> &mut WorkloadAnalyzer
pub fn workload_analyzer_mut(&mut self) -> &mut WorkloadAnalyzer
Get a mutable reference to the workload analyzer for recording samples.
Sourcepub fn resource_allocator_mut(&mut self) -> &mut ResourceAllocator
pub fn resource_allocator_mut(&mut self) -> &mut ResourceAllocator
Get a mutable reference to the resource allocator.