pub struct TaskScheduler { /* private fields */ }Expand description
Task scheduler
Implementations
Sourceimpl TaskScheduler
impl TaskScheduler
Sourcepub fn submit_task(&mut self, task: Task) -> Result<(), AmbientError>
pub fn submit_task(&mut self, task: Task) -> Result<(), AmbientError>
Submit task
Sourcepub fn get_pending_tasks(&self) -> Vec<Task>
pub fn get_pending_tasks(&self) -> Vec<Task>
Get pending tasks
pub fn get_pending_tasks_into( &self, out: &mut [TaskHandle], ) -> Result<usize, AmbientError>
Sourcepub fn dispatch_next(&mut self) -> Option<Task>
pub fn dispatch_next(&mut self) -> Option<Task>
Dispatch the next pending task to a device, moving it to running.
Returns the dispatched task, or None if no tasks are pending.
Sourcepub fn complete_task(
&mut self,
task_id: &str,
device_id: &str,
success: bool,
usage: ResourceUsage,
)
pub fn complete_task( &mut self, task_id: &str, device_id: &str, success: bool, usage: ResourceUsage, )
Mark a running task as completed, recording it in execution history.
Sourcepub fn running_count(&self) -> usize
pub fn running_count(&self) -> usize
Get the number of currently running tasks.
Sourcepub fn completed_count(&self) -> usize
pub fn completed_count(&self) -> usize
Get the number of completed tasks.
Sourcepub fn recent_history(&self, n: usize) -> &[TaskExecutionRecord]
pub fn recent_history(&self, n: usize) -> &[TaskExecutionRecord]
Get recent execution history records.
Sourcepub fn set_policy(&mut self, policy: SchedulingPolicy)
pub fn set_policy(&mut self, policy: SchedulingPolicy)
Set the scheduling policy.