pub struct GgmlBlockLayout {
pub block_elems: usize,
pub block_bytes: usize,
}Expand description
Elements per quantization block and packed byte size (from ggml).
Fields
block_elems: usizeblock_bytes: usizeTrait Implementations
Sourceimpl Clone for GgmlBlockLayout
impl Clone for GgmlBlockLayout
Sourcefn clone(&self) -> GgmlBlockLayout
fn clone(&self) -> GgmlBlockLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GgmlBlockLayout
impl Debug for GgmlBlockLayout
Sourceimpl PartialEq for GgmlBlockLayout
impl PartialEq for GgmlBlockLayout
Sourcefn eq(&self, other: &GgmlBlockLayout) -> bool
fn eq(&self, other: &GgmlBlockLayout) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for GgmlBlockLayout
impl Eq for GgmlBlockLayout
impl StructuralPartialEq for GgmlBlockLayout