pub fn begin_forward()Expand description
Call once at the start of each token’s forward so the layer cursor tracks layers 0..n_layer-1. No-op (one atomic load) when capture is off.
pub fn begin_forward()Call once at the start of each token’s forward so the layer cursor tracks layers 0..n_layer-1. No-op (one atomic load) when capture is off.