pub fn run_suite(cfgs: &[BenchConfig]) -> Vec<BenchResult>Expand description
Run a suite of cases, skipping any whose model file is absent.
pub fn run_suite(cfgs: &[BenchConfig]) -> Vec<BenchResult>Run a suite of cases, skipping any whose model file is absent.