pub fn default_toggle_space() -> ConfigurationSpaceExpand description
Build a default configuration space for inference toggle optimization.
This covers the main toggle parameters that ExperimentConfig::apply_toggles supports.
pub fn default_toggle_space() -> ConfigurationSpaceBuild a default configuration space for inference toggle optimization.
This covers the main toggle parameters that ExperimentConfig::apply_toggles supports.