pub fn read_volume_bytes(
storage_root: &Path,
record: &DicomSeriesRecord,
) -> Result<Vec<u8>, DicomIngestError>Expand description
Read a pixel payload slice from the blob store (single copy at FRB boundary).
pub fn read_volume_bytes(
storage_root: &Path,
record: &DicomSeriesRecord,
) -> Result<Vec<u8>, DicomIngestError>Read a pixel payload slice from the blob store (single copy at FRB boundary).