is_nogood

Function is_nogood 

pub fn is_nogood(env: Environment, nogoods: &[Environment]) -> bool
Is env inconsistent given nogoods? True iff env is a superset of any nogood (a nogood’s assumptions are all present, so the contradiction fires).