pub fn label_holds(label: &[Environment], context: Environment) -> boolExpand description
Does some environment in label hold under context? (ignoring consistency — see
holds_in). True iff any label environment is a subset of context.
pub fn label_holds(label: &[Environment], context: Environment) -> boolDoes some environment in label hold under context? (ignoring consistency — see
holds_in). True iff any label environment is a subset of context.