pub fn model_penalty(atoms: &[u64], model: u64, weak: &[WeakConstraint]) -> i64Expand description
Total penalty of model under weak: the sum of weights of the weak constraints whose body
holds in the model.
pub fn model_penalty(atoms: &[u64], model: u64, weak: &[WeakConstraint]) -> i64Total penalty of model under weak: the sum of weights of the weak constraints whose body
holds in the model.