estimate_capability

Function estimate_capability 

pub fn estimate_capability(prior: f32, present: u32, total: u32) -> f32
Bayesian estimate of P(holds capability | related achievements): a posterior from a prior and the fraction of related achievements that are present. Returns the prior unchanged if there is no related evidence. P = prior·L / (prior·L + (1−prior)·(1−L)), L = present/total.