pub fn stipulation_binding(capacity: CapacityStatus) -> boolExpand description
A stipulation by the agent is binding only when capacity is Intact.
pub fn stipulation_binding(capacity: CapacityStatus) -> boolA stipulation by the agent is binding only when capacity is Intact.