backdoor_satisfied

Function backdoor_satisfied 

pub fn backdoor_satisfied(
    edges: &[NQuin],
    x: u64,
    y: u64,
    z: &[u64],
    nodes: &[u64],
) -> bool
Backdoor criterion: a set z is admissible for estimating the effect of x on y iff (a) no node in z is a descendant of x, and (b) z blocks every backdoor (confounding) path — here, every common ancestor (confounder) of x and y is in z. nodes enumerates the model’s variables. Bounded, zero-heap (composes caused reachability).