pub fn rules_conflict(a: &DefeasibleRule, b: &DefeasibleRule) -> boolExpand description
Two rules conflict iff they conclude the same literal with opposite polarity.
pub fn rules_conflict(a: &DefeasibleRule, b: &DefeasibleRule) -> boolTwo rules conflict iff they conclude the same literal with opposite polarity.