abox_clash

Function abox_clash 

pub fn abox_clash(
    types: &[u64],
    disjoint: &[(u64, u64)],
    tbox: &[NQuin],
) -> bool
Clash detection (ABox consistency core): does an individual asserted to have all of types have a clash — two types that are disjoint, directly or via subsumption (t1 ⊑ X, t2 ⊑ Y, X disjoint Y)? Returns true on a clash (inconsistency). Zero-heap.