distributed_knowledge

Function distributed_knowledge 

pub fn distributed_knowledge(required: &[u64], known: &[u64]) -> bool
Distributed knowledge D φ: the group COLLECTIVELY knows φ by pooling — φ is entailed by the union of what agents individually know. Modelled over fact-fragments: φ is distributed- known iff every fragment in required appears in known (the union of all agents’ fragments).