pub struct SubgraphMatch {
pub mapping: [u64; 8],
pub len: u16,
pub missing_edges: u8,
}Expand description
One subgraph-isomorphism match: the data-graph node ids assigned to pattern
nodes 0..len. missing_edges is 0 for an exact (induced-monomorphism)
match and counts unsatisfied pattern edges for an approximate match.
Fields
mapping: [u64; 8]len: u16missing_edges: u8Trait Implementations
Sourceimpl Clone for SubgraphMatch
impl Clone for SubgraphMatch
Sourcefn clone(&self) -> SubgraphMatch
fn clone(&self) -> SubgraphMatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubgraphMatch
impl Debug for SubgraphMatch
Sourceimpl PartialEq for SubgraphMatch
impl PartialEq for SubgraphMatch
Sourcefn eq(&self, other: &SubgraphMatch) -> bool
fn eq(&self, other: &SubgraphMatch) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for SubgraphMatch
impl StructuralPartialEq for SubgraphMatch