pub fn and(a: Likeliness, b: Likeliness) -> LikelinessExpand description
Conjunction — the meet (weakest link): a claim resting on both a and b is no
more expected than its least-expected part.
pub fn and(a: Likeliness, b: Likeliness) -> LikelinessConjunction — the meet (weakest link): a claim resting on both a and b is no
more expected than its least-expected part.