pub fn combine_routes(routes: &[Likeliness]) -> LikelinessExpand description
Likeliness of a conclusion reachable by alternative routes = the strongest (join over
all). The vacuous disjunction (no routes) is Impossible (the bottom).
pub fn combine_routes(routes: &[Likeliness]) -> LikelinessLikeliness of a conclusion reachable by alternative routes = the strongest (join over
all). The vacuous disjunction (no routes) is Impossible (the bottom).