rebut

Function rebut 

pub fn rebut(conclusion: Likeliness, counter: Likeliness) -> Likeliness
Rebuttal. A counter-argument of strength counter (how expected it is that the conclusion is false) caps the conclusion at not(counter). A strong rebuttal defeats: a Certain conclusion rebutted by a Likely counter falls to Unlikely.