revise

Function revise 

pub fn revise(
    prior: Likeliness,
    support: Likeliness,
    against: Likeliness,
) -> Likeliness
Defeasible revision. Fold a new supporting route and a rebuttal into a prior: and(or(prior, support), not(against)). The support is an alternative route (best-of), and the rebuttal caps the result. Symmetric in the sense that a strong against overrides any amount of support.