structural_rule_licensed

Function structural_rule_licensed 

pub fn structural_rule_licensed(rule: StructuralRule, reusable: bool) -> bool
Is applying rule to a formula with the given reusability licensed? Exchange always; Weakening and Contraction only on a reusable (!-marked) formula — applying either to a linear resource is an illegal proof step (resources must be used exactly once).