pub struct IdentifierBinding {
pub identifier: u64,
pub scheme: CryptoScheme,
pub attested: bool,
pub confidence: f32,
}Expand description
One identifier in an enumerated identity: a handle, the crypto scheme attesting
it, whether an attestation is actually present, and the confidence (strictly in
(0,1)) that this identifier picks out the natural person.
Fields
identifier: u64q_hash of the identifier (DID, key id, handle, …).
scheme: CryptoSchemeattested: boolconfidence: f32Trait Implementations
Sourceimpl Clone for IdentifierBinding
impl Clone for IdentifierBinding
Sourcefn clone(&self) -> IdentifierBinding
fn clone(&self) -> IdentifierBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdentifierBinding
impl Debug for IdentifierBinding
Sourceimpl PartialEq for IdentifierBinding
impl PartialEq for IdentifierBinding
Sourcefn eq(&self, other: &IdentifierBinding) -> bool
fn eq(&self, other: &IdentifierBinding) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for IdentifierBinding
impl StructuralPartialEq for IdentifierBinding