pub struct ShapeViolation {
pub shape: u64,
pub focus_node: u64,
pub severity: ShaclSeverity,
}Expand description
A SHACL shape violation against a focus node, with its severity.
Fields
shape: u64focus_node: u64severity: ShaclSeverityTrait Implementations
Sourceimpl Clone for ShapeViolation
impl Clone for ShapeViolation
Sourcefn clone(&self) -> ShapeViolation
fn clone(&self) -> ShapeViolation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShapeViolation
impl Debug for ShapeViolation
Sourceimpl PartialEq for ShapeViolation
impl PartialEq for ShapeViolation
Sourcefn eq(&self, other: &ShapeViolation) -> bool
fn eq(&self, other: &ShapeViolation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ShapeViolation
impl Eq for ShapeViolation
impl StructuralPartialEq for ShapeViolation