pub fn evaluate_manifold_answer_sets(
states: &[ManifoldState10D],
out: &mut [u64],
) -> usizeExpand description
Derive bounded topology facts from manifold states and run the real Gelfond-Lifschitz answer-set evaluator.
pub fn evaluate_manifold_answer_sets(
states: &[ManifoldState10D],
out: &mut [u64],
) -> usizeDerive bounded topology facts from manifold states and run the real Gelfond-Lifschitz answer-set evaluator.