pub fn global_saturation(consistent: usize, isolated: usize) -> f32Expand description
Global inconsistency saturation: the fraction of routed quins that were isolated as
contradictory (from route_paraconsistent’s counts). total == 0 → 0.0.
pub fn global_saturation(consistent: usize, isolated: usize) -> f32Global inconsistency saturation: the fraction of routed quins that were isolated as
contradictory (from route_paraconsistent’s counts). total == 0 → 0.0.