pub enum Rcc8Relation {
Disconnected,
ExternallyConnected,
PartiallyOverlapping,
TangentiallyProperPart,
TangentiallyProperPartInverse,
NonTangentialProperPart,
NonTangentialProperPartInverse,
Equal,
}Expand description
RCC8 spatial relations for topological reasoning
Variants
Disconnected
Region A is disconnected from Region B
ExternallyConnected
Region A is externally connected to Region B (touches at boundary)
PartiallyOverlapping
Region A is partially overlapping with Region B
TangentiallyProperPart
Region A is tangentially proper part of Region B (touches boundary)
TangentiallyProperPartInverse
Region A is tangentially proper part inverse of Region B
NonTangentialProperPart
Region A is non-tangential proper part of Region B (completely inside)
NonTangentialProperPartInverse
Region A is non-tangential proper part inverse of Region B
Equal
Region A is equal to Region B