evaluate_since

Function evaluate_since 

pub fn evaluate_since(trace: &[NQuin], p: u64, q: u64) -> bool
Since p S q: at the end of the trace, q held at some past point and p has held at every point since (inclusive of after q). Retrospective legal analysis (“the duty has held since the breach”). Zero-heap.