pub struct RegisteredEndpoint {
pub url: String,
pub purpose: String,
pub trigger: String,
}Expand description
An outbound network endpoint that an adapter requires access to.
Fields
url: Stringpurpose: Stringtrigger: StringTrait Implementations
Sourceimpl Clone for RegisteredEndpoint
impl Clone for RegisteredEndpoint
Sourcefn clone(&self) -> RegisteredEndpoint
fn clone(&self) -> RegisteredEndpoint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegisteredEndpoint
impl Debug for RegisteredEndpoint
Sourceimpl Hash for RegisteredEndpoint
impl Hash for RegisteredEndpoint
Sourceimpl PartialEq for RegisteredEndpoint
impl PartialEq for RegisteredEndpoint
Sourcefn eq(&self, other: &RegisteredEndpoint) -> bool
fn eq(&self, other: &RegisteredEndpoint) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for RegisteredEndpoint
impl StructuralPartialEq for RegisteredEndpoint