pub struct BackendRegistry { /* private fields */ }Expand description
The registry of acceleration methods. Heap-using and boot-time only (the heavy probe runs once and is cached in the passport — never on a hot path).
Implementations
Sourceimpl BackendRegistry
impl BackendRegistry
pub fn new() -> Self
Sourcepub fn register(&mut self, backend: Box<dyn ProbeableBackend>) -> &mut Self
pub fn register(&mut self, backend: Box<dyn ProbeableBackend>) -> &mut Self
Register a backend. Adding one here is the only change needed to bring a new acceleration method into the benchmark, ranking and policy.
Sourcepub fn iter(&self) -> impl Iterator<Item = &dyn ProbeableBackend>
pub fn iter(&self) -> impl Iterator<Item = &dyn ProbeableBackend>
All registered backends (including currently-unavailable ones).
Sourcepub fn available(&self) -> impl Iterator<Item = &dyn ProbeableBackend>
pub fn available(&self) -> impl Iterator<Item = &dyn ProbeableBackend>
Backends actually usable on this host.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool