pub struct HardwareVelocity {
pub target: ComputeTarget,
pub bytes_per_second: f64,
pub sample_count: u64,
pub last_updated: Option<Instant>,
}Expand description
Hardware velocity metrics for a specific compute target
Fields
target: ComputeTargetbytes_per_second: f64sample_count: u64last_updated: Option<Instant>Implementations
Sourceimpl HardwareVelocity
impl HardwareVelocity
pub fn new(target: ComputeTarget) -> Self
Sourcepub fn update(&mut self, bytes_processed: u64, duration: Duration)
pub fn update(&mut self, bytes_processed: u64, duration: Duration)
Update velocity with a new sample using exponential moving average
Sourcepub fn get_velocity(&self) -> f64
pub fn get_velocity(&self) -> f64
Get current velocity with default fallback if no samples