pub fn encode_block_postings(postings: &BlockFieldPostings) -> Vec<u8> ⓘExpand description
Encode one SuperBlock’s three fields. Chooses Bloom when it is strictly smaller than the exact posting list.
pub fn encode_block_postings(postings: &BlockFieldPostings) -> Vec<u8> ⓘEncode one SuperBlock’s three fields. Chooses Bloom when it is strictly smaller than the exact posting list.