pub struct BidxBlockRange {
pub start: usize,
pub end: usize,
}Expand description
A contiguous half-open block interval selected by an object hash.
The interval can be much larger than a caller output buffer. Use
BidxMatchPage to enumerate it without allocating one Vec entry per
matching block.
Fields
start: usizeend: usizeImplementations