pub struct Q42ObjectMatchPage {
pub block_range: BidxBlockRange,
pub returned: usize,
pub next_cursor: Option<Q42ObjectSearchCursor>,
}Expand description
One page of exact object matches written by Q42RangeVolume::find_object_into.
Fields
block_range: BidxBlockRangereturned: usizenext_cursor: Option<Q42ObjectSearchCursor>Trait Implementations
Sourceimpl Clone for Q42ObjectMatchPage
impl Clone for Q42ObjectMatchPage
Sourcefn clone(&self) -> Q42ObjectMatchPage
fn clone(&self) -> Q42ObjectMatchPage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Q42ObjectMatchPage
impl Debug for Q42ObjectMatchPage
Sourceimpl PartialEq for Q42ObjectMatchPage
impl PartialEq for Q42ObjectMatchPage
Sourcefn eq(&self, other: &Q42ObjectMatchPage) -> bool
fn eq(&self, other: &Q42ObjectMatchPage) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for Q42ObjectMatchPage
impl Eq for Q42ObjectMatchPage
impl StructuralPartialEq for Q42ObjectMatchPage