pub struct Q42RangeQueryPattern {
pub subject: Option<u64>,
pub predicate: Option<u64>,
pub object: Option<u64>,
pub context: Option<u64>,
}Expand description
A simple physical pattern for range-backed Q42 scans. None is an
unbound SPARQL position. The planner selects the BIDX object index when
object is bound and otherwise performs a bounded sequential block scan.
Fields
subject: Option<u64>predicate: Option<u64>object: Option<u64>context: Option<u64>Trait Implementations
Sourceimpl Clone for Q42RangeQueryPattern
impl Clone for Q42RangeQueryPattern
Sourcefn clone(&self) -> Q42RangeQueryPattern
fn clone(&self) -> Q42RangeQueryPattern
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Q42RangeQueryPattern
impl Debug for Q42RangeQueryPattern
Sourceimpl Default for Q42RangeQueryPattern
impl Default for Q42RangeQueryPattern
Sourcefn default() -> Q42RangeQueryPattern
fn default() -> Q42RangeQueryPattern
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for Q42RangeQueryPattern
impl PartialEq for Q42RangeQueryPattern
Sourcefn eq(&self, other: &Q42RangeQueryPattern) -> bool
fn eq(&self, other: &Q42RangeQueryPattern) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for Q42RangeQueryPattern
impl Eq for Q42RangeQueryPattern
impl StructuralPartialEq for Q42RangeQueryPattern