pub enum SemanticModality<'a> {
Text(&'a str),
AudioHash(&'a [u8]),
CeremonialVisual(&'a [u8]),
PhoneticSchema(&'a [u8]),
Visual(&'a [u8]),
Spatial3D(&'a [u8]),
Biosignal(&'a [u8]),
Molecular(&'a [u8]),
QuantumPhysical(&'a [u8]),
SpatioTemporalTrace(&'a [u8]),
Custom {
tag: u32,
bytes: &'a [u8],
},
}Expand description
Represents the pluralistic forms that a semantic concept can take. We explicitly reject the assumption that knowledge is exclusively bound to Unicode strings.
Variants
Text(&'a str)
AudioHash(&'a [u8])
CeremonialVisual(&'a [u8])
PhoneticSchema(&'a [u8])
Visual(&'a [u8])
Spatial3D(&'a [u8])
Biosignal(&'a [u8])
Molecular(&'a [u8])
QuantumPhysical(&'a [u8])
SpatioTemporalTrace(&'a [u8])
Custom