validate_shacl_property

Function validate_shacl_property 

pub fn validate_shacl_property(
    quins: &[NQuin],
    target_subject: u64,
    target_property: u64,
    constraints: &[ShaclConstraint],
) -> bool
Evaluates a slice of NQuins against a set of constraints for a specific target property hash. Returns true if valid, false if a constraint violation occurs.