import_asset

Function import_asset 

pub fn import_asset(
    bytes: &[u8],
    hint: Option<&str>,
) -> Result<Mesh, AssetError>
Import a mesh, sniffing the format from the bytes (or trusting an explicit lowercase extension hint like "obj" / "stl").