pub fn compile_developmental_asset(
source_bytes: &[u8],
hint: Option<&str>,
asset_uri: &str,
source_format: &str,
gestational_age_days: u16,
carnegie_stage: u8,
) -> Result<CompiledAsset, Compile10dError>Expand description
Like compile_asset but binds the compiled asset to a point on the developmental t-axis — its
gestational_age_days (postfertilization) and carnegie_stage. This is the compile step for a fetal/
embryonic stage: consecutive stages, ordered by gestational age, form a 4-D developmental body (the
maternal–fetal dyad’s fetal side, reproductive-continuum plan 2).