pub enum DaemonError {
ResolverNotInitialized,
DigUnavailable,
DnssecLookupFailed,
CborLdParsingFailed,
InvalidDomain,
PeerNotFound,
}Expand description
Error type for daemon swarm DNSSEC bootstrap operations.
Variants
ResolverNotInitialized
DNSSEC resolver has not been initialized on the worker cell
The dig command was unavailable or returned a failure
DnssecLookupFailed
DNSSEC lookup completed but no valid CBOR-LD payload was found
CborLdParsingFailed
CBOR-LD payload could not be parsed into Quin pointers
InvalidDomain
The supplied domain was not parseable into an endpoint
PeerNotFound
The requested peer id is unknown to the worker cell