pub struct MicropaymentInstruction {
pub recipient_label: String,
pub ilp_address: String,
pub amount_micro_cents: u64,
pub use_nym: bool,
}Expand description
A single resolved micropayment instruction in a dispatch plan.
Fields
recipient_label: Stringilp_address: Stringamount_micro_cents: u64use_nym: boolTrait Implementations
Sourceimpl Clone for MicropaymentInstruction
impl Clone for MicropaymentInstruction
Sourcefn clone(&self) -> MicropaymentInstruction
fn clone(&self) -> MicropaymentInstruction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MicropaymentInstruction
impl Debug for MicropaymentInstruction
Sourceimpl<'de> Deserialize<'de> for MicropaymentInstruction
impl<'de> Deserialize<'de> for MicropaymentInstruction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for MicropaymentInstruction
impl PartialEq for MicropaymentInstruction
Sourcefn eq(&self, other: &MicropaymentInstruction) -> bool
fn eq(&self, other: &MicropaymentInstruction) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MicropaymentInstruction
impl Serialize for MicropaymentInstruction
impl StructuralPartialEq for MicropaymentInstruction