pub struct Escrow {
pub job_id: u64,
pub requester_did: u64,
pub provider_did: u64,
pub amount_micro_units: u64,
pub provider_ilp: String,
pub use_nym: bool,
pub state: EscrowState,
}Expand description
An escrow for one paid job.
Fields
job_id: u64requester_did: u64provider_did: u64amount_micro_units: u64provider_ilp: StringWhere the provider is paid if verified (an ILP payment pointer / address).
use_nym: boolstate: EscrowStateImplementations
Sourceimpl Escrow
impl Escrow
Sourcepub fn offer(
job_id: u64,
requester_did: u64,
provider_did: u64,
amount_micro_units: u64,
provider_ilp: impl Into<String>,
use_nym: bool,
) -> Self
pub fn offer( job_id: u64, requester_did: u64, provider_did: u64, amount_micro_units: u64, provider_ilp: impl Into<String>, use_nym: bool, ) -> Self
Open an escrow in the Offered state for an agreed price.
Sourcepub fn hold(&mut self) -> Result<(), SwarmError>
pub fn hold(&mut self) -> Result<(), SwarmError>
Commit the funds to escrow (Offered → Held). Tracked only — no transfer.
Sourcepub fn settle(
&mut self,
verdict: VerificationVerdict,
) -> Result<SettlementOutcome, SwarmError>
pub fn settle( &mut self, verdict: VerificationVerdict, ) -> Result<SettlementOutcome, SwarmError>
Settle the escrow according to a verification verdict. Must be Held.
Verified→ReleasedToProvider, returns the provider payment instruction.Rejected→RefundedToRequester, returns a refund (no provider payment).
This is the only path to a provider payment, and it is impossible to reach
without a Verified verdict.