EmbeddingTable

Struct EmbeddingTable 

pub struct EmbeddingTable {
    pub model: ScoreModel,
    pub rank: usize,
    pub ent_dim: usize,
    pub rel_dim: usize,
    pub n_entities: usize,
    pub n_relations: usize,
    pub entities: Vec<f64>,
    pub relations: Vec<f64>,
}
A trained (or freshly-initialised) embedding table: one vector per entity and one per relation. The storage length per entity/relation is fixed by the model and the rank k (see ScoreModel::dims).

Fields

model: ScoreModelrank: usize

Rank (the conceptual embedding dimension). Storage may be k or 2k per vector depending on the model.

ent_dim: usizerel_dim: usizen_entities: usizen_relations: usizeentities: Vec<f64>

n_entities * ent_dim, row-major.

relations: Vec<f64>

n_relations * rel_dim, row-major.

Implementations

Source

impl EmbeddingTable

pub fn zeros( model: ScoreModel, k: usize, n_entities: usize, n_relations: usize, ) -> Result<Self, KgEmbeddingError>

Allocate a zeroed table sized for model at rank k.

pub fn entity(&self, i: usize) -> Result<&[f64], KgEmbeddingError>

pub fn relation(&self, i: usize) -> Result<&[f64], KgEmbeddingError>

pub fn entity_mut(&mut self, i: usize) -> &mut [f64]

pub fn relation_mut(&mut self, i: usize) -> &mut [f64]

pub fn score( &self, h: usize, r: usize, t: usize, ) -> Result<f64, KgEmbeddingError>

Plausibility score for triple (h, r, t) (entity/relation indices). Higher = more plausible. Fails closed on out-of-range indices.