pub struct BootstrapCi {
pub estimate: f64,
pub lower: f64,
pub upper: f64,
pub confidence: f64,
pub method: CiMethod,
}Expand description
An earned confidence interval — derived by resampling the data, not assumed from a Gaussian.
Fields
estimate: f64lower: f64upper: f64confidence: f64method: CiMethodTrait Implementations
Sourceimpl Clone for BootstrapCi
impl Clone for BootstrapCi
Sourcefn clone(&self) -> BootstrapCi
fn clone(&self) -> BootstrapCi
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BootstrapCi
impl Debug for BootstrapCi
Sourceimpl PartialEq for BootstrapCi
impl PartialEq for BootstrapCi
Sourcefn eq(&self, other: &BootstrapCi) -> bool
fn eq(&self, other: &BootstrapCi) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for BootstrapCi
impl StructuralPartialEq for BootstrapCi