pub struct JobQueue { /* private fields */ }Expand description
In-process job queue. HTTP dispatch is performed by the caller via
submit_fn passed to process_queue.
Implementations
Sourceimpl JobQueue
impl JobQueue
pub fn new() -> Self
Sourcepub async fn process_queue<F>(&self, dispatch: F) -> Result<(), QpuError>
pub async fn process_queue<F>(&self, dispatch: F) -> Result<(), QpuError>
Drain the pending queue and call dispatch for each job.
dispatch should return the provider-assigned job ID on success.
Sourcepub async fn record_result(&self, job_id: &str, result: QpuResult)
pub async fn record_result(&self, job_id: &str, result: QpuResult)
Mark a running job as completed or failed based on a polled status.
Sourcepub async fn take_results(&self) -> Vec<QpuResult>
pub async fn take_results(&self) -> Vec<QpuResult>
Drain and return all completed results.
pub async fn stats(&self) -> QueueStats