pub struct MannWhitneyResult {
pub u: f64,
pub p_value: f64,
pub n1: usize,
pub n2: usize,
}Expand description
Mann-Whitney U test (rank sum) for two independent samples. Returns U statistic, p approx using normal for large n, or exact for small. Simplified normal approx for demo.
Fields
u: f64p_value: f64n1: usizen2: usizeTrait Implementations
Sourceimpl Clone for MannWhitneyResult
impl Clone for MannWhitneyResult
Sourcefn clone(&self) -> MannWhitneyResult
fn clone(&self) -> MannWhitneyResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MannWhitneyResult
impl Debug for MannWhitneyResult
Sourceimpl PartialEq for MannWhitneyResult
impl PartialEq for MannWhitneyResult
Sourcefn eq(&self, other: &MannWhitneyResult) -> bool
fn eq(&self, other: &MannWhitneyResult) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for MannWhitneyResult
impl StructuralPartialEq for MannWhitneyResult