trimmed_mean

Function trimmed_mean 

pub fn trimmed_mean(values: &[f64], proportion: f64) -> Option<f64>
Trimmed mean: drop a proportion (in [0, 0.5)) of the data from each end and average the rest. proportion = 0 is the ordinary mean. None if empty or proportion is out of range.