pub struct KineticsCalculator { /* private fields */ }Expand description
Kinetics calculator
Implementations
Sourceimpl KineticsCalculator
impl KineticsCalculator
pub fn new() -> Self
Sourcepub fn add_rate_law(&mut self, law: RateLaw)
pub fn add_rate_law(&mut self, law: RateLaw)
Register a rate law under its law_id, replacing any existing entry.
Sourcepub fn get_rate_law(&self, law_id: &str) -> Option<&RateLaw>
pub fn get_rate_law(&self, law_id: &str) -> Option<&RateLaw>
Look up a rate law by id.
Sourcepub fn list_rate_laws(&self) -> Vec<String>
pub fn list_rate_laws(&self) -> Vec<String>
List the ids of all registered rate laws.
Sourcepub fn add_rate_constant(&mut self, constant: RateConstant)
pub fn add_rate_constant(&mut self, constant: RateConstant)
Register a rate constant under its constant_id, replacing any existing entry.
Sourcepub fn get_rate_constant(&self, constant_id: &str) -> Option<&RateConstant>
pub fn get_rate_constant(&self, constant_id: &str) -> Option<&RateConstant>
Look up a rate constant by id.
Sourcepub fn list_rate_constants(&self) -> Vec<String>
pub fn list_rate_constants(&self) -> Vec<String>
List the ids of all registered rate constants.
Sourcepub fn set_reaction_rate(&mut self, reaction_id: &str, rate: f64)
pub fn set_reaction_rate(&mut self, reaction_id: &str, rate: f64)
Record the instantaneous rate for a reaction id.
Sourcepub fn get_reaction_rate(&self, reaction_id: &str) -> Option<&f64>
pub fn get_reaction_rate(&self, reaction_id: &str) -> Option<&f64>
Look up the recorded rate for a reaction id.
Sourcepub fn list_reaction_rates(&self) -> Vec<String>
pub fn list_reaction_rates(&self) -> Vec<String>
List the reaction ids that have a recorded rate.
pub fn initialize(&mut self) -> Result<(), ChemistryError>