required_vertices

Function required_vertices 

pub fn required_vertices(vertex_count: usize) -> usize
Upper bound on the vertex output slots needed for an input of vertex_count vertices. Decimation never adds vertices, so the input count is the bound.