pub struct TriTriSegment {
pub start: Point3,
pub end: Point3,
}Expand description
The (approximate, f64-constructed) intersection segment of two triangles.
Only meaningful when tri_tri_intersect_3 reported true for the
non-coplanar case; for coplanar overlaps there is an intersection area,
not a single segment, and no segment is produced.
Fields
start: Point3end: Point3Trait Implementations
Sourceimpl Clone for TriTriSegment
impl Clone for TriTriSegment
Sourcefn clone(&self) -> TriTriSegment
fn clone(&self) -> TriTriSegment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TriTriSegment
impl Debug for TriTriSegment
Sourceimpl PartialEq for TriTriSegment
impl PartialEq for TriTriSegment
Sourcefn eq(&self, other: &TriTriSegment) -> bool
fn eq(&self, other: &TriTriSegment) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for TriTriSegment
impl StructuralPartialEq for TriTriSegment