pub enum SystemModel {
Series,
Parallel,
KOutOfN {
k: usize,
n: usize,
},
}Expand description
System reliability model topology used by
ReliabilityAnalyzer::analyze_reliability.
Series => all components must work; Parallel => at least one must work;
KOutOfN { k, n } => at least k of the n components must work (the n
here must equal the number of components supplied in the
ReliabilityConfig).
Variants