pub struct BatchOptimizer { /* private fields */ }Expand description
Batch optimizer
Implementations
Sourceimpl BatchOptimizer
impl BatchOptimizer
pub fn new() -> Self
pub fn initialize(&mut self) -> Result<(), MLError>
Sourcepub fn register_algorithm(
&mut self,
name: &str,
algorithm: BatchOptimizationAlgorithm,
)
pub fn register_algorithm( &mut self, name: &str, algorithm: BatchOptimizationAlgorithm, )
Register a batch optimization algorithm under the given name.
Sourcepub fn get_algorithm(&self, name: &str) -> Option<&BatchOptimizationAlgorithm>
pub fn get_algorithm(&self, name: &str) -> Option<&BatchOptimizationAlgorithm>
Get a registered batch optimization algorithm by name.
Sourcepub fn list_algorithms(&self) -> Vec<String>
pub fn list_algorithms(&self) -> Vec<String>
List the names of all registered batch optimization algorithms.
Sourcepub fn optimization_metrics(&self) -> &BatchOptimizationMetrics
pub fn optimization_metrics(&self) -> &BatchOptimizationMetrics
Return a reference to the optimization metrics.
Sourcepub fn optimization_metrics_mut(&mut self) -> &mut BatchOptimizationMetrics
pub fn optimization_metrics_mut(&mut self) -> &mut BatchOptimizationMetrics
Return a mutable reference to the optimization metrics.