pub struct QueueManager { /* private fields */ }Expand description
Queue manager
Implementations
Sourceimpl QueueManager
impl QueueManager
pub fn new() -> Self
Sourcepub fn enqueue(&mut self, request: InferenceRequest)
pub fn enqueue(&mut self, request: InferenceRequest)
Enqueue a pending inference request.
Sourcepub fn dequeue(&mut self) -> Option<InferenceRequest>
pub fn dequeue(&mut self) -> Option<InferenceRequest>
Dequeue the next pending request (FIFO order).
Sourcepub fn start_request(&mut self, running: RunningRequest)
pub fn start_request(&mut self, running: RunningRequest)
Mark a request as running on a given backend.
Sourcepub fn complete_request(
&mut self,
request_id: &str,
completed: CompletedRequest,
)
pub fn complete_request( &mut self, request_id: &str, completed: CompletedRequest, )
Mark a running request as completed, removing it from the running set and appending it to the completed list.
Sourcepub fn pending_requests(&self) -> &[InferenceRequest]
pub fn pending_requests(&self) -> &[InferenceRequest]
Return a reference to the pending requests queue.
Sourcepub fn running_requests(&self) -> &HashMap<String, RunningRequest>
pub fn running_requests(&self) -> &HashMap<String, RunningRequest>
Return a reference to the running requests map.
Sourcepub fn completed_requests(&self) -> &[CompletedRequest]
pub fn completed_requests(&self) -> &[CompletedRequest]
Return a reference to the completed requests list.
Sourcepub fn pending_count(&self) -> usize
pub fn pending_count(&self) -> usize
Number of pending requests.
Sourcepub fn running_count(&self) -> usize
pub fn running_count(&self) -> usize
Number of currently running requests.