pub struct TrainingOptimizer { /* private fields */ }Expand description
Training optimizer
Implementations
Sourceimpl TrainingOptimizer
impl TrainingOptimizer
pub fn new() -> Self
pub fn initialize(&mut self) -> Result<(), MLError>
Sourcepub fn register_algorithm(
&mut self,
name: &str,
algorithm: TrainingOptimizationAlgorithm,
)
pub fn register_algorithm( &mut self, name: &str, algorithm: TrainingOptimizationAlgorithm, )
Register a training optimization algorithm under the given name.
Sourcepub fn get_algorithm(
&self,
name: &str,
) -> Option<&TrainingOptimizationAlgorithm>
pub fn get_algorithm( &self, name: &str, ) -> Option<&TrainingOptimizationAlgorithm>
Get a registered training optimization algorithm by name.
Sourcepub fn list_algorithms(&self) -> Vec<String>
pub fn list_algorithms(&self) -> Vec<String>
List the names of all registered training optimization algorithms.
Sourcepub fn early_stopping(&self) -> &EarlyStopping
pub fn early_stopping(&self) -> &EarlyStopping
Return a reference to the early-stopping configuration.
Sourcepub fn early_stopping_mut(&mut self) -> &mut EarlyStopping
pub fn early_stopping_mut(&mut self) -> &mut EarlyStopping
Return a mutable reference to the early-stopping configuration.