pub struct TuningHistory { /* private fields */ }Expand description
Tuning history
Implementations
Sourceimpl TuningHistory
impl TuningHistory
pub fn new() -> Self
Sourcepub fn add_record(&mut self, record: TuningRecord)
pub fn add_record(&mut self, record: TuningRecord)
Append a tuning record to the history.
Sourcepub fn records(&self) -> &[TuningRecord]
pub fn records(&self) -> &[TuningRecord]
Return a reference to all tuning records.
Sourcepub fn record_best_configuration(
&mut self,
objective: &str,
config: TuningConfiguration,
)
pub fn record_best_configuration( &mut self, objective: &str, config: TuningConfiguration, )
Record a best configuration for a given objective name.
Sourcepub fn get_best_configuration(
&self,
objective: &str,
) -> Option<&TuningConfiguration>
pub fn get_best_configuration( &self, objective: &str, ) -> Option<&TuningConfiguration>
Get the best configuration for a given objective.
Sourcepub fn list_best_configurations(&self) -> Vec<String>
pub fn list_best_configurations(&self) -> Vec<String>
List the objective names that have a recorded best configuration.