pub struct UtilizationTracker { /* private fields */ }Expand description
Utilization tracker
Implementations
Sourceimpl UtilizationTracker
impl UtilizationTracker
pub fn new() -> Self
pub fn initialize(&mut self) -> Result<(), MLError>
Sourcepub fn record_utilization(&mut self, record: UtilizationRecord)
pub fn record_utilization(&mut self, record: UtilizationRecord)
Record a utilization sample for a resource, appending it to the history and updating the current utilization value.
Sourcepub fn get_utilization_history(&self, resource_id: &str) -> &[UtilizationRecord]
pub fn get_utilization_history(&self, resource_id: &str) -> &[UtilizationRecord]
Return the utilization history for a given resource.
Sourcepub fn current_utilization(&self, resource_id: &str) -> Option<f64>
pub fn current_utilization(&self, resource_id: &str) -> Option<f64>
Return the current utilization for a given resource.
Sourcepub fn set_current_utilization(&mut self, resource_id: &str, utilization: f64)
pub fn set_current_utilization(&mut self, resource_id: &str, utilization: f64)
Set the current utilization for a given resource.