pub struct AccessPatterns { /* private fields */ }Expand description
Access patterns
Implementations
Sourceimpl AccessPatterns
impl AccessPatterns
pub fn new() -> Self
Sourcepub fn add_read_pattern(&mut self, name: &str, pattern: AccessPattern)
pub fn add_read_pattern(&mut self, name: &str, pattern: AccessPattern)
Register a read access pattern under the given name.
Sourcepub fn get_read_pattern(&self, name: &str) -> Option<&AccessPattern>
pub fn get_read_pattern(&self, name: &str) -> Option<&AccessPattern>
Get a read access pattern by name, if any.
Sourcepub fn add_write_pattern(&mut self, name: &str, pattern: AccessPattern)
pub fn add_write_pattern(&mut self, name: &str, pattern: AccessPattern)
Register a write access pattern under the given name.
Sourcepub fn get_write_pattern(&self, name: &str) -> Option<&AccessPattern>
pub fn get_write_pattern(&self, name: &str) -> Option<&AccessPattern>
Get a write access pattern by name, if any.
Sourcepub fn add_temporal_pattern(&mut self, name: &str, pattern: TemporalPattern)
pub fn add_temporal_pattern(&mut self, name: &str, pattern: TemporalPattern)
Register a temporal pattern under the given name.
Sourcepub fn get_temporal_pattern(&self, name: &str) -> Option<&TemporalPattern>
pub fn get_temporal_pattern(&self, name: &str) -> Option<&TemporalPattern>
Get a temporal pattern by name, if any.