pub struct InitialConditions { /* private fields */ }Expand description
Initial conditions
Implementations
Sourceimpl InitialConditions
impl InitialConditions
pub fn new() -> Self
Sourcepub fn set_condition(
&mut self,
field_id: &str,
cond_type: InitialConditionType,
values: Vec<f64>,
)
pub fn set_condition( &mut self, field_id: &str, cond_type: InitialConditionType, values: Vec<f64>, )
Register an initial condition for a field: its type and the initial values.
Sourcepub fn get_condition_type(
&self,
field_id: &str,
) -> Option<&InitialConditionType>
pub fn get_condition_type( &self, field_id: &str, ) -> Option<&InitialConditionType>
Get the initial condition type registered for a field, if any.
Sourcepub fn get_condition_values(&self, field_id: &str) -> Option<&Vec<f64>>
pub fn get_condition_values(&self, field_id: &str) -> Option<&Vec<f64>>
Get the initial condition values registered for a field, if any.
Sourcepub fn remove_condition(&mut self, field_id: &str)
pub fn remove_condition(&mut self, field_id: &str)
Remove a field’s initial condition (type and values).
Sourcepub fn list_condition_fields(&self) -> Vec<String>
pub fn list_condition_fields(&self) -> Vec<String>
List all field IDs that have a registered initial condition.
Sourcepub fn add_perturbation(&mut self, field_id: &str, perturbation: Perturbation)
pub fn add_perturbation(&mut self, field_id: &str, perturbation: Perturbation)
Add a perturbation for a field.
Sourcepub fn get_perturbation(&self, field_id: &str) -> Option<&Perturbation>
pub fn get_perturbation(&self, field_id: &str) -> Option<&Perturbation>
Get the perturbation registered for a field, if any.
Sourcepub fn list_perturbation_fields(&self) -> Vec<String>
pub fn list_perturbation_fields(&self) -> Vec<String>
List all field IDs that have a registered perturbation.