pub struct ObjectiveFunction { /* private fields */ }Expand description
Objective function
Implementations
Sourceimpl ObjectiveFunction
impl ObjectiveFunction
pub fn new() -> Self
Sourcepub fn get_function_id(&self) -> &str
pub fn get_function_id(&self) -> &str
Get the function ID.
Sourcepub fn get_function_type(&self) -> &ObjectiveFunctionType
pub fn get_function_type(&self) -> &ObjectiveFunctionType
Get the function type.
Sourcepub fn set_function_type(&mut self, ftype: ObjectiveFunctionType)
pub fn set_function_type(&mut self, ftype: ObjectiveFunctionType)
Set the function type.
Sourcepub fn is_gradient_available(&self) -> bool
pub fn is_gradient_available(&self) -> bool
Returns whether a gradient is available for this objective function.
Sourcepub fn set_gradient_available(&mut self, available: bool)
pub fn set_gradient_available(&mut self, available: bool)
Set whether a gradient is available.
Sourcepub fn is_hessian_available(&self) -> bool
pub fn is_hessian_available(&self) -> bool
Returns whether a Hessian is available for this objective function.
Sourcepub fn set_hessian_available(&mut self, available: bool)
pub fn set_hessian_available(&mut self, available: bool)
Set whether a Hessian is available.