pub struct AlertSystem { /* private fields */ }Expand description
Alert system
Implementations
Sourceimpl AlertSystem
impl AlertSystem
pub fn new() -> Self
pub fn initialize(&mut self) -> Result<(), StatisticalError>
Sourcepub fn alert_types(&self) -> &[AlertType]
pub fn alert_types(&self) -> &[AlertType]
Returns the list of registered alert types.
Sourcepub fn add_alert_type(&mut self, alert_type: AlertType)
pub fn add_alert_type(&mut self, alert_type: AlertType)
Register an additional alert type if not already present.
Sourcepub fn notification_channels(&self) -> &[NotificationChannel]
pub fn notification_channels(&self) -> &[NotificationChannel]
Returns the list of registered notification channels.
Sourcepub fn add_notification_channel(&mut self, channel: NotificationChannel)
pub fn add_notification_channel(&mut self, channel: NotificationChannel)
Register an additional notification channel if not already present.
Sourcepub fn add_escalation_policy(&mut self, policy: EscalationPolicy)
pub fn add_escalation_policy(&mut self, policy: EscalationPolicy)
Register an escalation policy.
Sourcepub fn escalation_policies(&self) -> &[EscalationPolicy]
pub fn escalation_policies(&self) -> &[EscalationPolicy]
Returns the list of registered escalation policies.
Sourcepub fn get_escalation_policy(
&self,
policy_id: &str,
) -> Option<&EscalationPolicy>
pub fn get_escalation_policy( &self, policy_id: &str, ) -> Option<&EscalationPolicy>
Look up an escalation policy by id.
Sourcepub fn escalation_policy_count(&self) -> usize
pub fn escalation_policy_count(&self) -> usize
Returns the number of registered escalation policies.