pub struct AnomalyDetection { /* private fields */ }Expand description
Anomaly detection
Implementations
Sourceimpl AnomalyDetection
impl AnomalyDetection
pub fn new() -> Self
pub fn initialize(&mut self) -> Result<(), StatisticalError>
Sourcepub fn detection_algorithms(&self) -> &[DetectionAlgorithm]
pub fn detection_algorithms(&self) -> &[DetectionAlgorithm]
Returns the list of registered detection algorithms.
Sourcepub fn add_detection_algorithm(&mut self, algorithm: DetectionAlgorithm)
pub fn add_detection_algorithm(&mut self, algorithm: DetectionAlgorithm)
Register an additional detection algorithm if not already present.
Sourcepub fn threshold_methods(&self) -> &[ThresholdMethod]
pub fn threshold_methods(&self) -> &[ThresholdMethod]
Returns the list of registered threshold methods.
Sourcepub fn add_threshold_method(&mut self, method: ThresholdMethod)
pub fn add_threshold_method(&mut self, method: ThresholdMethod)
Register an additional threshold method if not already present.
Sourcepub fn alert_system(&self) -> &AlertSystem
pub fn alert_system(&self) -> &AlertSystem
Returns a reference to the alert system.
Sourcepub fn alert_system_mut(&mut self) -> &mut AlertSystem
pub fn alert_system_mut(&mut self) -> &mut AlertSystem
Returns a mutable reference to the alert system.