pub struct ForecastingEngine { /* private fields */ }Expand description
Forecasting engine
Implementations
Sourceimpl ForecastingEngine
impl ForecastingEngine
pub fn new() -> Self
pub fn initialize(&mut self) -> Result<(), StatisticalError>
Sourcepub fn forecasting_models(&self) -> &[ForecastingModel]
pub fn forecasting_models(&self) -> &[ForecastingModel]
Returns the list of registered forecasting models.
Sourcepub fn add_forecasting_model(&mut self, model: ForecastingModel)
pub fn add_forecasting_model(&mut self, model: ForecastingModel)
Register an additional forecasting model if not already present.
Sourcepub fn supports_forecasting_model(&self, model: &ForecastingModel) -> bool
pub fn supports_forecasting_model(&self, model: &ForecastingModel) -> bool
Returns true when the given forecasting model is registered.
Sourcepub fn accuracy_metrics(&self) -> &AccuracyMetrics
pub fn accuracy_metrics(&self) -> &AccuracyMetrics
Returns a reference to the current accuracy metrics.
Sourcepub fn set_accuracy_metrics(&mut self, metrics: AccuracyMetrics)
pub fn set_accuracy_metrics(&mut self, metrics: AccuracyMetrics)
Update the accuracy metrics after a forecasting run.
Sourcepub fn model_selection(&self) -> &ModelSelection
pub fn model_selection(&self) -> &ModelSelection
Returns a reference to the model selection subsystem.
Sourcepub fn model_selection_mut(&mut self) -> &mut ModelSelection
pub fn model_selection_mut(&mut self) -> &mut ModelSelection
Returns a mutable reference to the model selection subsystem.