pub struct ModelSelection { /* private fields */ }Expand description
Model selection
Implementations
Sourceimpl ModelSelection
impl ModelSelection
pub fn new() -> Self
pub fn initialize(&mut self) -> Result<(), StatisticalError>
Sourcepub fn selection_criteria(&self) -> &[SelectionCriterion]
pub fn selection_criteria(&self) -> &[SelectionCriterion]
Returns the list of registered selection criteria.
Sourcepub fn add_selection_criterion(&mut self, criterion: SelectionCriterion)
pub fn add_selection_criterion(&mut self, criterion: SelectionCriterion)
Register an additional selection criterion if not already present.
Sourcepub fn cross_validation(&self) -> &CrossValidation
pub fn cross_validation(&self) -> &CrossValidation
Returns a reference to the cross-validation configuration.
Sourcepub fn cross_validation_mut(&mut self) -> &mut CrossValidation
pub fn cross_validation_mut(&mut self) -> &mut CrossValidation
Returns a mutable reference to the cross-validation configuration.
Sourcepub fn hyperparameter_tuning(&self) -> &HyperparameterTuning
pub fn hyperparameter_tuning(&self) -> &HyperparameterTuning
Returns a reference to the hyperparameter tuning configuration.
Sourcepub fn hyperparameter_tuning_mut(&mut self) -> &mut HyperparameterTuning
pub fn hyperparameter_tuning_mut(&mut self) -> &mut HyperparameterTuning
Returns a mutable reference to the hyperparameter tuning configuration.