pub struct PatternRecognition { /* private fields */ }Expand description
Pattern recognition
Implementations
Sourceimpl PatternRecognition
impl PatternRecognition
pub fn new() -> Self
pub fn initialize(&mut self) -> Result<(), StatisticalError>
Sourcepub fn pattern_types(&self) -> &[PatternType]
pub fn pattern_types(&self) -> &[PatternType]
Returns the list of pattern types this recognizer looks for.
Sourcepub fn add_pattern_type(&mut self, pattern_type: PatternType)
pub fn add_pattern_type(&mut self, pattern_type: PatternType)
Register an additional pattern type if not already present.
Sourcepub fn recognition_algorithms(&self) -> &[RecognitionAlgorithm]
pub fn recognition_algorithms(&self) -> &[RecognitionAlgorithm]
Returns the list of recognition algorithms available.
Sourcepub fn add_recognition_algorithm(&mut self, algorithm: RecognitionAlgorithm)
pub fn add_recognition_algorithm(&mut self, algorithm: RecognitionAlgorithm)
Register an additional recognition algorithm if not already present.
Sourcepub fn pattern_library(&self) -> &PatternLibrary
pub fn pattern_library(&self) -> &PatternLibrary
Returns a reference to the pattern library.
Sourcepub fn pattern_library_mut(&mut self) -> &mut PatternLibrary
pub fn pattern_library_mut(&mut self) -> &mut PatternLibrary
Returns a mutable reference to the pattern library.