pub struct RandomForestFitResult {
pub n_trees: usize,
pub classifier: bool,
pub train_metric: f64,
pub n: usize,
pub n_features: usize,
}Expand description
Summary of a fitted random forest, with the in-sample fit metric (R² for a regression forest, classification accuracy for a classifier).
Fields
n_trees: usizeclassifier: booltrain_metric: f64R² (regressor) or accuracy in [0,1] (classifier), measured in-sample.
n: usizen_features: usizeTrait Implementations
Sourceimpl Clone for RandomForestFitResult
impl Clone for RandomForestFitResult
Sourcefn clone(&self) -> RandomForestFitResult
fn clone(&self) -> RandomForestFitResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for RandomForestFitResult
impl RefUnwindSafe for RandomForestFitResult
impl Send for RandomForestFitResult
impl Sync for RandomForestFitResult
impl Unpin for RandomForestFitResult
impl UnsafeUnpin for RandomForestFitResult
impl UnwindSafe for RandomForestFitResult