pub struct SecureAggregation { /* private fields */ }Expand description
Secure aggregation
Implementations
Sourceimpl SecureAggregation
impl SecureAggregation
pub fn new() -> Self
pub fn initialize(&mut self) -> Result<(), StatisticalError>
Sourcepub fn aggregation_protocols(&self) -> &[AggregationProtocol]
pub fn aggregation_protocols(&self) -> &[AggregationProtocol]
Returns the list of registered aggregation protocols.
Sourcepub fn add_aggregation_protocol(&mut self, protocol: AggregationProtocol)
pub fn add_aggregation_protocol(&mut self, protocol: AggregationProtocol)
Register an additional aggregation protocol if not already present.
Sourcepub fn encryption_schemes(&self) -> &[EncryptionScheme]
pub fn encryption_schemes(&self) -> &[EncryptionScheme]
Returns the list of registered encryption schemes.
Sourcepub fn add_encryption_scheme(&mut self, scheme: EncryptionScheme)
pub fn add_encryption_scheme(&mut self, scheme: EncryptionScheme)
Register an additional encryption scheme if not already present.
Sourcepub fn add_integrity_check(&mut self, check: IntegrityCheck)
pub fn add_integrity_check(&mut self, check: IntegrityCheck)
Register an integrity check.
Sourcepub fn integrity_checks(&self) -> &[IntegrityCheck]
pub fn integrity_checks(&self) -> &[IntegrityCheck]
Returns the list of registered integrity checks.
Sourcepub fn get_integrity_check(&self, check_id: &str) -> Option<&IntegrityCheck>
pub fn get_integrity_check(&self, check_id: &str) -> Option<&IntegrityCheck>
Look up an integrity check by id.
Sourcepub fn integrity_check_count(&self) -> usize
pub fn integrity_check_count(&self) -> usize
Returns the number of registered integrity checks.