pub struct StatisticalAccelerator { /* private fields */ }Expand description
Statistical accelerator
Implementations
Sourceimpl StatisticalAccelerator
impl StatisticalAccelerator
pub fn new() -> Self
pub fn initialize(&mut self) -> Result<(), StatisticalError>
Sourcepub fn acceleration_strategies(&self) -> &[AccelerationStrategy]
pub fn acceleration_strategies(&self) -> &[AccelerationStrategy]
Returns the list of acceleration strategies enabled on this accelerator.
Sourcepub fn add_acceleration_strategy(&mut self, strategy: AccelerationStrategy)
pub fn add_acceleration_strategy(&mut self, strategy: AccelerationStrategy)
Enable an additional acceleration strategy if not already present.
Sourcepub fn has_acceleration_strategy(&self, strategy: &AccelerationStrategy) -> bool
pub fn has_acceleration_strategy(&self, strategy: &AccelerationStrategy) -> bool
Returns true when the given strategy is enabled.
Sourcepub fn add_hardware_accelerator(&mut self, accelerator: HardwareAccelerator)
pub fn add_hardware_accelerator(&mut self, accelerator: HardwareAccelerator)
Register a hardware accelerator.
Sourcepub fn hardware_accelerators(&self) -> &[HardwareAccelerator]
pub fn hardware_accelerators(&self) -> &[HardwareAccelerator]
Returns the list of registered hardware accelerators.
Sourcepub fn get_hardware_accelerator(
&self,
accelerator_id: &str,
) -> Option<&HardwareAccelerator>
pub fn get_hardware_accelerator( &self, accelerator_id: &str, ) -> Option<&HardwareAccelerator>
Look up a hardware accelerator by id.
Sourcepub fn hardware_accelerator_count(&self) -> usize
pub fn hardware_accelerator_count(&self) -> usize
Returns the number of registered hardware accelerators.