pub struct StatisticalAnalysisEngine { /* private fields */ }Expand description
Statistical analysis engine
Implementations
Sourceimpl StatisticalAnalysisEngine
impl StatisticalAnalysisEngine
pub fn new() -> Self
pub fn initialize(&mut self) -> Result<(), StatisticalError>
Sourcepub fn analysis_algorithms(&self) -> &[AnalysisAlgorithm]
pub fn analysis_algorithms(&self) -> &[AnalysisAlgorithm]
Returns the list of analysis algorithms available to this engine.
Sourcepub fn add_analysis_algorithm(&mut self, algorithm: AnalysisAlgorithm)
pub fn add_analysis_algorithm(&mut self, algorithm: AnalysisAlgorithm)
Register an additional analysis algorithm if not already present.
Sourcepub fn supports_analysis_algorithm(&self, algorithm: &AnalysisAlgorithm) -> bool
pub fn supports_analysis_algorithm(&self, algorithm: &AnalysisAlgorithm) -> bool
Returns true when the given analysis algorithm is registered.
Sourcepub fn pattern_recognition(&self) -> &PatternRecognition
pub fn pattern_recognition(&self) -> &PatternRecognition
Returns a reference to the pattern recognition subsystem.
Sourcepub fn pattern_recognition_mut(&mut self) -> &mut PatternRecognition
pub fn pattern_recognition_mut(&mut self) -> &mut PatternRecognition
Returns a mutable reference to the pattern recognition subsystem.
Sourcepub fn anomaly_detection(&self) -> &AnomalyDetection
pub fn anomaly_detection(&self) -> &AnomalyDetection
Returns a reference to the anomaly detection subsystem.
Sourcepub fn anomaly_detection_mut(&mut self) -> &mut AnomalyDetection
pub fn anomaly_detection_mut(&mut self) -> &mut AnomalyDetection
Returns a mutable reference to the anomaly detection subsystem.
Sourcepub fn forecasting_engine(&self) -> &ForecastingEngine
pub fn forecasting_engine(&self) -> &ForecastingEngine
Returns a reference to the forecasting engine.
Sourcepub fn forecasting_engine_mut(&mut self) -> &mut ForecastingEngine
pub fn forecasting_engine_mut(&mut self) -> &mut ForecastingEngine
Returns a mutable reference to the forecasting engine.