pub fn open_storage<P: AsRef<Path>>(data_dir: P) -> Box<dyn StorageDriver>Expand description
Open the best available storage driver for this platform and hardware.
Call log_startup_diagnostics() before this if you want WSL2 warnings in logs.
pub fn open_storage<P: AsRef<Path>>(data_dir: P) -> Box<dyn StorageDriver>Open the best available storage driver for this platform and hardware.
Call log_startup_diagnostics() before this if you want WSL2 warnings in logs.