pub fn is_nogood(env: Environment, nogoods: &[Environment]) -> boolExpand description
Is env inconsistent given nogoods? True iff env is a superset of any nogood (a nogood’s
assumptions are all present, so the contradiction fires).
pub fn is_nogood(env: Environment, nogoods: &[Environment]) -> boolIs env inconsistent given nogoods? True iff env is a superset of any nogood (a nogood’s
assumptions are all present, so the contradiction fires).