pub fn is_binding_contract(
stipulated: bool,
accepted: bool,
offeror: CapacityStatus,
acceptor: CapacityStatus,
) -> boolExpand description
A contract is binding iff it was stipulated, assented to, AND both parties had intact
juridical capacity (composes capacity::stipulation_binding — an agreement assented to under
duress or by an incapacitated party does not bind).