pub fn is_necessary_cause(
graph: &[NQuin],
root: u64,
candidate: u64,
effect: u64,
) -> boolExpand description
But-for causal necessity: candidate is a NECESSARY cause of effect (from
origin root) iff effect is reachable from root, but is NOT reachable once
candidate is removed from the causal graph. The attribution/liability test
(“would the harm have occurred but for this agent’s act?”). Zero-heap.