pub struct GraphProofReport {
pub source_records: u64,
pub q42_records: u64,
pub source_unique_records: u64,
pub q42_unique_records: u64,
pub missing_from_q42: u64,
pub unexpected_in_q42: u64,
pub first_missing: Option<[u64; 4]>,
pub first_unexpected: Option<[u64; 4]>,
pub source_skipped_lines: u64,
pub source_contains_blank_nodes: bool,
pub rdf_isomorphism: RdfIsomorphismStatus,
}Expand description
Result of an exact, external-sort comparison.
Fields
source_records: u64Number of N-Triples accepted by the CLI-compatible normaliser.
q42_records: u64Number of Q42 Quins examined.
source_unique_records: u64Number of unique encoded quads in the source.
q42_unique_records: u64Number of unique encoded quads in the Q42 volume.
missing_from_q42: u64Source records that do not occur in the Q42 set.
unexpected_in_q42: u64Q42 records that do not occur in the source set.
first_missing: Option<[u64; 4]>A representative missing encoded quad, if any.
first_unexpected: Option<[u64; 4]>A representative unexpected encoded quad, if any.
source_skipped_lines: u64Lines skipped because they are blank, comments, or not accepted by the same three-token N-Triples compatibility parser used by CLI ingest.
source_contains_blank_nodes: boolrdf_isomorphism: RdfIsomorphismStatusImplementations
Sourceimpl GraphProofReport
impl GraphProofReport
Sourcepub fn encoded_sets_match(&self) -> bool
pub fn encoded_sets_match(&self) -> bool
Exact equality of the two encoded RDF default-graph sets.