pub fn run_derivation_job(
source_bytes: &[u8],
format_hint: Option<&str>,
media_type: &str,
licence: &str,
vc_payload: Option<&[u8]>,
) -> Result<Vec<u8>, DerivationError>Expand description
Run the decoupled derivation job on an original source asset.
Takes the raw source bytes, imports them into a mesh, wraps the source bytes and
metadata into a ProvenanceSidecar, and compiles it all into a sealed .10d container.