pub struct HeCiphertextRef {
pub store_id: u64,
pub key_id_hash: u64,
pub parameter_fingerprint: u64,
pub commitment_lo: u64,
pub commitment_hi: u64,
/* private fields */
}Expand description
Fixed-size ABI reference to a ciphertext held in an external bounded store.
This is exactly 48 bytes (six u64s), like NQuin, but it is not semantic RDF
data and does not overload any Quin bit fields.
Fields
store_id: u64key_id_hash: u64parameter_fingerprint: u64commitment_lo: u64commitment_hi: u64Implementations